--- uboot.old/common/cmd_bootm.c	2009-08-10 22:12:45.000000000 +0530
+++ uboot/common/cmd_bootm.c	2009-08-10 22:06:57.000000000 +0530
@@ -129,6 +129,7 @@
 #ifdef CONFIG_SILENT_CONSOLE
 static void fixup_silent_linux (void);
 #endif
+static void fixup_verbose (void);
 #ifdef CONFIG_PASS_PLATFORM_ID
 static void set_platform_id(void);
 static void set_cmdline(void);
@@ -168,8 +169,16 @@
 	char	*name, *s;
 	int	(*appl)(int, char *[]);
 	image_header_t *hdr = &header;
-
+	unsigned short verbose_check=0;
+	char *verbose;
 	s = getenv ("verify");
+	verbose = getenv ("verbose");
+	
+	if(verbose!=NULL)
+			verbose_check = ((strncmp(verbose,"false",5)==0)||(strncmp(verbose,"FALSE",5)==0)||(strncmp(verbose,"0",1)==0))? 1 : 0;
+	else
+			verbose_check = 1;
+
 	verify = (s && (*s == 'n')) ? 0 : 1;
 
 	if (argc < 2) {
@@ -179,6 +188,8 @@
 	}
 
 	SHOW_BOOT_PROGRESS (1);
+	
+	if(verbose_check!=1)
 	printf ("## Booting image at %08lx ...\n", addr);
 
 	/* Copy header so we can blank CRC field for re-calculation */
@@ -206,6 +217,7 @@
 		} else
 #endif	/* __I386__ */
 	    {
+				if(verbose_check!=1)
 		puts ("Bad Magic Number\n");
 		SHOW_BOOT_PROGRESS (-1);
 		return 1;
@@ -220,6 +232,7 @@
 	hdr->ih_hcrc = 0;
 
 	if (crc32 (0, (uchar *)data, len) != checksum) {
+			if(verbose_check!=1)
 		puts ("Bad Header Checksum\n");
 		SHOW_BOOT_PROGRESS (-2);
 		return 1;
@@ -249,12 +262,15 @@
 	len  = ntohl(hdr->ih_size);
 
 	if (verify) {
+			if(verbose_check!=1)
 		puts ("   Verifying Checksum ... ");
 		if (crc32 (0, (uchar *)data, len) != ntohl(hdr->ih_dcrc)) {
+				if(verbose_check!=1)
 			printf ("Bad Data CRC\n");
 			SHOW_BOOT_PROGRESS (-3);
 			return 1;
 		}
+		if(verbose_check!=1)
 		puts ("OK\n");
 		console_init_f ();
 	}
@@ -286,6 +302,7 @@
 # error Unknown CPU type
 #endif
 	{
+			if(verbose_check!=1)
 		printf ("Unsupported Architecture 0x%x\n", hdr->ih_arch);
 		SHOW_BOOT_PROGRESS (-4);
 		return 1;
@@ -311,7 +328,9 @@
 		for (i=1; len_ptr[i]; ++i)
 			data += 4;
 		break;
-	default: printf ("Wrong Image Type for %s command\n", cmdtp->name);
+	default:
+		if(verbose_check!=1) 
+				printf ("Wrong Image Type for %s command\n", cmdtp->name);
 		SHOW_BOOT_PROGRESS (-5);
 		return 1;
 	}
@@ -345,7 +364,7 @@
 			size_t l = len;
 			void *to = (void *)ntohl(hdr->ih_load);
 			void *from = (void *)data;
-
+			if(verbose_check!=1)
 			printf ("   Loading %s ... ", name);
 
 			while (l > 0) {
@@ -362,9 +381,11 @@
 		}
 		break;
 	case IH_COMP_GZIP:
+		if(verbose_check!=1)
 		printf ("   Uncompressing %s ... ", name);
 		if (gunzip ((void *)ntohl(hdr->ih_load), unc_len,
 			    (uchar *)data, &len) != 0) {
+				if(verbose_check!=1)
 			puts ("GUNZIP ERROR - must RESET board to recover\n");
 			SHOW_BOOT_PROGRESS (-6);
 			do_reset (cmdtp, flag, argc, argv);
@@ -372,6 +393,7 @@
 		break;
 #ifdef CONFIG_BZIP2
 	case IH_COMP_BZIP2:
+		if(verbose_check!=1)
 		printf ("   Uncompressing %s ... ", name);
 		/*
 		 * If we've got less than 4 MB of malloc() space,
@@ -382,6 +404,7 @@
 						&unc_len, (char *)data, len,
 						CFG_MALLOC_LEN < (4096 * 1024), 0);
 		if (i != BZ_OK) {
+				if(verbose_check!=1)
 			printf ("BUNZIP2 ERROR %d - must RESET board to recover\n", i);
 			SHOW_BOOT_PROGRESS (-6);
 			udelay(100000);
@@ -392,10 +415,12 @@
 	default:
 		if (iflag)
 			enable_interrupts();
+		if(verbose_check!=1)
 		printf ("Unimplemented compression type %d\n", hdr->ih_comp);
 		SHOW_BOOT_PROGRESS (-7);
 		return 1;
 	}
+	if(verbose_check!=1)
 	puts ("OK\n");
 	SHOW_BOOT_PROGRESS (7);
 
@@ -423,6 +448,7 @@
 	default:
 		if (iflag)
 			enable_interrupts();
+		if(verbose_check!=1)
 		printf ("Can't boot image type %d\n", hdr->ih_type);
 		SHOW_BOOT_PROGRESS (-8);
 		return 1;
@@ -435,6 +461,11 @@
 #ifdef CONFIG_SILENT_CONSOLE
 	    fixup_silent_linux();
 #endif
+		fixup_verbose(); 
+ #ifdef CONFIG_PASS_PLATFORM_ID
+ 	    set_platform_id ();
+ #endif
+
 #ifdef CONFIG_PASS_PLATFORM_ID
 	set_cmdline();
 #endif
@@ -479,6 +510,7 @@
 
 	SHOW_BOOT_PROGRESS (-9);
 #ifdef DEBUG
+	if(verbose_check!=1)
 	puts ("\n## Control returned to monitor - resetting...\n");
 	do_reset (cmdtp, flag, argc, argv);
 #endif
@@ -652,6 +684,50 @@
 }
 #endif /* CONFIG_SILENT_CONSOLE */
 
+static void fixup_verbose (void)
+{
+	char buf[256]={0},*start, *end;
+	char *cmdline = getenv ("bootargs");
+	char *verbose = getenv ("verbose");
+	char *verbose_default="false";
+	if(verbose==NULL)
+		verbose=verbose_default;
+
+	if(verbose!=NULL)
+	{
+			if((strcmp(verbose,"false")==0) || (strcmp(verbose,"FALSE")==0) ||
+							(strcmp(verbose,"0")==0))
+			{
+					//printf("Before Verbose Settings:%s\n", cmdline);
+					if(cmdline)
+					{
+							if((start=strstr(cmdline,"console=")) != NULL)
+							{
+									strncpy(buf,cmdline,(start-cmdline));
+									//printf("\n\nAfter Copying Buffer:%s\n", buf);
+									end = strchr(start,' ');
+									if(end)
+											strcat(buf,end+1);
+
+									strcat(buf," console=/dev/null");
+									//printf("\n\nCheck point 2:%s\n", buf);
+							}			
+							else
+							{
+									strcpy(buf, cmdline);
+									strcat(buf, " console=/dev/null");
+							}
+					}
+					else
+					{
+							strcpy(buf,"console=/dev/null");
+					}
+					setenv ("bootargs", buf);
+					//printf("After Verbose Settings:%s\n", buf);
+			}
+	}
+}
+
 #ifdef CONFIG_PPC
 static void  __attribute__((noinline))
 do_bootm_linux (cmd_tbl_t *cmdtp, int flag,
@@ -1456,33 +1532,46 @@
 	time_t timestamp = (time_t)ntohl(hdr->ih_time);
 	struct rtc_time tm;
 #endif
+	char *verbose=getenv("verbose");
+	unsigned short verbose_check=0;
 
+	if(verbose!=NULL)
+			verbose_check=((strncmp(verbose,"false",5)==0)||(strncmp(verbose,"FALSE",5)==0)||(strncmp(verbose,"0",1)==0))? 1: 0;
+	else
+			verbose_check=1;
+	//printf("verbose_check to verify:%d\n",verbose_check);
+	if(!verbose_check)
 	printf ("   Image Name:   %.*s\n", IH_NMLEN, hdr->ih_name);
 #if (CONFIG_COMMANDS & CFG_CMD_DATE) || defined(CONFIG_TIMESTAMP)
 	to_tm (timestamp, &tm);
+	if(verbose_check!=1)
 	printf ("   Created:      %4d-%02d-%02d  %2d:%02d:%02d UTC\n",
 		tm.tm_year, tm.tm_mon, tm.tm_mday,
 		tm.tm_hour, tm.tm_min, tm.tm_sec);
 #endif	/* CFG_CMD_DATE, CONFIG_TIMESTAMP */
+	if(verbose_check!=1)
+	{
 	puts ("   Image Type:   "); print_type(hdr);
 	printf ("\n   Data Size:    %d Bytes = ", ntohl(hdr->ih_size));
 	print_size (ntohl(hdr->ih_size), "\n");
 	printf ("   Load Address: %08x\n"
 		"   Entry Point:  %08x\n",
 		 ntohl(hdr->ih_load), ntohl(hdr->ih_ep));
-
+	}
 	if (hdr->ih_type == IH_TYPE_MULTI) {
 		int i;
 		ulong len;
 		ulong *len_ptr = (ulong *)((ulong)hdr + sizeof(image_header_t));
-
+		if(verbose_check!=1)
 		puts ("   Contents:\n");
 		for (i=0; (len = ntohl(*len_ptr)); ++i, ++len_ptr) {
+				if(verbose_check!=1){
 			printf ("   Image %d: %8ld Bytes = ", i, len);
 			print_size (len, "\n");
 		}
 	}
 }
+}
 
 
 static void
